@@ -10,7 +10,7 @@ from lamin_logger import logger
 from ._db import insert
 from ._settings_instance import InstanceSettings
 from ._settings_user import UserSettings
-from ._setup_schema import get_schema_module_name
+from ._setup_schema import create_schema_if_not_exists, get_schema_module_name
 
 
 def check_migrate(
@@ -26,19 +26,19 @@ def check_migrate(
         schema_names = []
 
     for schema_name in ["core"] + schema_names:
+        create_schema_if_not_exists(schema_name, isettings)
         schema_module = importlib.import_module(get_schema_module_name(schema_name))
         if schema_module._migration is None:
             status.append("migrate-unnecessary")
             continue
 
-        schema_id = str(
-            schema_module._schema_id
-            if hasattr(schema_module, "_schema_id")
-            else schema_module._schema,
-        )  # backward compat
+        schema_id = schema_module._schema_id
 
         with sqm.Session(isettings.db_engine()) as session:
-            version_table = getattr(schema_module, f"version_{schema_id}")
+            table_loc = (
+                schema_module.dev if hasattr(schema_module, "dev") else schema_module
+            )
+            version_table = getattr(table_loc, f"version_{schema_id}")
             versions = session.exec(sqm.select(version_table.v)).all()
 
         current_version = schema_module.__version__
